searchData={"items":[{"type":"module","title":"Membrane.Opus.Decoder","doc":"This element performs decoding of Opus audio.","ref":"Membrane.Opus.Decoder.html"},{"type":"module","title":"Element options - Membrane.Opus.Decoder","doc":"Passed via struct `t:Membrane.Opus.Decoder.t/0`\n\n- `sample_rate`  \n\n  ```\n  8000 | 12000 | 16000 | 24000 | 48000\n  ```\n  \n  Default value: `48000`  \n  Sample rate to decode at. Note: Opus is able to decode any stream\n  at any supported sample rate. 48 kHz is recommended. For details,\n  see https://tools.ietf.org/html/rfc7845#section-5.1 point 5.","ref":"Membrane.Opus.Decoder.html#module-element-options"},{"type":"module","title":"Pads - Membrane.Opus.Decoder","doc":"### `:input`\n\nAccepted formats:\n```\n%Opus{self_delimiting?: false}\n```\n```\n%RemoteStream{type: :packetized, content_format: format} when format in [Opus, nil]\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\n\n\n### `:output`\n\nAccepted formats:\n```\n%RawAudio{sample_format: :s16le}\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`","ref":"Membrane.Opus.Decoder.html#module-pads"},{"type":"function","title":"Membrane.Opus.Decoder.options/0","doc":"Returns description of options available for this module","ref":"Membrane.Opus.Decoder.html#options/0"},{"type":"type","title":"Membrane.Opus.Decoder.t/0","doc":"Struct containing options for `Membrane.Opus.Decoder`","ref":"Membrane.Opus.Decoder.html#t:t/0"},{"type":"module","title":"Membrane.Opus.Encoder","doc":"This element performs encoding of Opus audio into a raw stream. You'll need to parse the stream and then package it into a container in order to use it.","ref":"Membrane.Opus.Encoder.html"},{"type":"module","title":"Element options - Membrane.Opus.Encoder","doc":"Passed via struct `t:Membrane.Opus.Encoder.t/0`\n\n- `application`  \n\n  ```\n  allowed_applications()\n  ```\n  \n  Default value: `:audio`  \n  Output type (similar to compression amount).\n  \n  See https://opus-codec.org/docs/opus_api-1.3.1/group__opus__encoder.html#gaa89264fd93c9da70362a0c9b96b9ca88.\n\n\n- `input_stream_format`  \n\n  ```\n  RawAudio.t()\n  ```\n  \n  Default value: `nil`  \n  Input type - used to set input sample rate and channels.","ref":"Membrane.Opus.Encoder.html#module-element-options"},{"type":"module","title":"Pads - Membrane.Opus.Encoder","doc":"### `:input`\n\nAccepted formats:\n```\n%RawAudio{sample_format: :s16le, channels: channels, sample_rate: sample_rate}\nwhen channels in @allowed_channels and sample_rate in @allowed_sample_rates\n```\n```\nMembrane.RemoteStream\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\n\n\n### `:output`\n\nAccepted formats:\n```\n%Opus{self_delimiting?: false}\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`","ref":"Membrane.Opus.Encoder.html#module-pads"},{"type":"function","title":"Membrane.Opus.Encoder.options/0","doc":"Returns description of options available for this module","ref":"Membrane.Opus.Encoder.html#options/0"},{"type":"type","title":"Membrane.Opus.Encoder.allowed_applications/0","doc":"","ref":"Membrane.Opus.Encoder.html#t:allowed_applications/0"},{"type":"type","title":"Membrane.Opus.Encoder.allowed_channels/0","doc":"","ref":"Membrane.Opus.Encoder.html#t:allowed_channels/0"},{"type":"type","title":"Membrane.Opus.Encoder.allowed_sample_rates/0","doc":"","ref":"Membrane.Opus.Encoder.html#t:allowed_sample_rates/0"},{"type":"type","title":"Membrane.Opus.Encoder.t/0","doc":"Struct containing options for `Membrane.Opus.Encoder`","ref":"Membrane.Opus.Encoder.html#t:t/0"},{"type":"module","title":"Membrane.Opus.Parser","doc":"Parses a raw incoming Opus stream and adds stream_format information, as well as metadata.\n\nAdds the following metadata:\n\nduration :: non_neg_integer()\n  Number of nanoseconds encoded in this packet","ref":"Membrane.Opus.Parser.html"},{"type":"module","title":"Element options - Membrane.Opus.Parser","doc":"Passed via struct `t:Membrane.Opus.Parser.t/0`\n\n- `delimitation`  \n\n  ```\n  delimitation_t()\n  ```\n  \n  Default value: `:keep`  \n  If input is delimitted? (as indicated by the `self_delimiting?`\n  field in %Opus) and `:undelimit` is selected, will remove delimiting.\n  \n  If input is not delimitted? and `:delimit` is selected, will add delimiting.\n  \n  If `:keep` is selected, will not change delimiting.\n  \n  Otherwise will act like `:keep`.\n  \n  See https://tools.ietf.org/html/rfc6716#appendix-B for details\n  on the self-delimiting Opus format.\n\n\n- `input_delimitted?`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `false`  \n  If you know that the input is self-delimitted? but you're reading from\n  some element that isn't sending the correct structure, you can set this\n  to true to force the Parser to assume the input is self-delimitted? and\n  ignore upstream stream_format information on self-delimitation.","ref":"Membrane.Opus.Parser.html#module-element-options"},{"type":"module","title":"Pads - Membrane.Opus.Parser","doc":"### `:input`\n\nAccepted formats:\n```\nOpus\n```\n```\n%RemoteStream{content_format: format} when format in [Opus, nil]\n```\n\nDirection: | `:input`\nAvailability: | `:always`\nFlow control: | `:auto`\n\n\n### `:output`\n\nAccepted formats:\n```\nOpus\n```\n\nDirection: | `:output`\nAvailability: | `:always`\nFlow control: | `:auto`","ref":"Membrane.Opus.Parser.html#module-pads"},{"type":"function","title":"Membrane.Opus.Parser.options/0","doc":"Returns description of options available for this module","ref":"Membrane.Opus.Parser.html#options/0"},{"type":"type","title":"Membrane.Opus.Parser.delimitation_t/0","doc":"","ref":"Membrane.Opus.Parser.html#t:delimitation_t/0"},{"type":"type","title":"Membrane.Opus.Parser.t/0","doc":"Struct containing options for `Membrane.Opus.Parser`","ref":"Membrane.Opus.Parser.html#t:t/0"},{"type":"extras","title":"Membrane Opus plugin","doc":"# Membrane Opus plugin\n\n[![Hex.pm](https://img.shields.io/hexpm/v/membrane_opus_plugin.svg)](https://hex.pm/packages/membrane_opus_plugin)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/membrane_opus_plugin/)\n[![CircleCI](https://circleci.com/gh/membraneframework/membrane_opus_plugin.svg?style=svg)](https://circleci.com/gh/membraneframework/membrane_opus_plugin)\n\nOpus encoder and decoder.\n\nIt is a part of [Membrane Multimedia Framework](https://membrane.stream).","ref":"readme.html"},{"type":"extras","title":"Installation - Membrane Opus plugin","doc":"The package can be installed by adding `membrane_opus_plugin` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:membrane_opus_plugin, \"~> 0.19.0\"}\n  ]\nend\n```\n\nThis package depends on [libopus](http://opus-codec.org/docs/) library. The precompiled builds will be pulled and linked automatically. However, should there be any problems, consider installing it manually.\n\n#","ref":"readme.html#installation"},{"type":"extras","title":"Manual instalation of dependencies - Membrane Opus plugin","doc":"##","ref":"readme.html#manual-instalation-of-dependencies"},{"type":"extras","title":"Ubuntu - Membrane Opus plugin","doc":"```\nsudo apt-get install libopus-dev\n```\n\n##","ref":"readme.html#ubuntu"},{"type":"extras","title":"Arch/Manjaro - Membrane Opus plugin","doc":"```\npacman -S opus\n```\n\n##","ref":"readme.html#arch-manjaro"},{"type":"extras","title":"MacOS - Membrane Opus plugin","doc":"```\nbrew install opus\n```\n\n##","ref":"readme.html#macos"},{"type":"extras","title":"MacOS M1/M2 (Apple silicon) - Membrane Opus plugin","doc":"On Apple M1/M2 chips, one needs to export variables:\n```\nexport C_INCLUDE_PATH=$C_INCLUDE_PATH:$(brew --cellar)/opus/1.3.1/include\nexport LIBRARY_PATH=$LIBRARY_PATH:$(brew --cellar)/opus/1.3.1/lib\n```\nOn different local setups, directory and version names may differ.","ref":"readme.html#macos-m1-m2-apple-silicon"},{"type":"extras","title":"Usage - Membrane Opus plugin","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"Encoder - Membrane Opus plugin","doc":"The pipeline encodes a sample raw file and saves it as an opus file:\n\n```elixir\ndefmodule Membrane.ReleaseTest.Pipeline do\n  use Membrane.Pipeline\n  alias Membrane.RawAudio\n\n  @input_filename \"/tmp/input.raw\"\n  @output_filename \"/tmp/output.opus\"\n\n  @impl true\n  def handle_init(_ctx, _options) do\n    structure = \n      child(:source, %Membrane.File.Source{\n        location: @input_filename\n      })\n      |> child(:encoder, %Membrane.Opus.Encoder{\n        application: :audio,\n        input_stream_format: %RawAudio{\n          channels: 2,\n          sample_format: :s16le,\n          sample_rate: 48_000\n        }\n      })\n      |> child(:parser, %Membrane.Opus.Parser{delimitation: :delimit})\n      |> child(:sink, %Membrane.File.Sink{\n        location: @output_filename\n      })\n\n    {[spec: structure], %{}}\n  end\nend\n```\n\nOpus audio generally needs to be packaged in an [Ogg container](https://xiph.org/ogg/) in order to be played by a\nmedia player. See `Membrane.Ogg.Payloader` in the [Membrane Ogg Plugin](https://github.com/membraneframework/membrane_ogg_plugin).\n\n\n#","ref":"readme.html#encoder"},{"type":"extras","title":"Decoder - Membrane Opus plugin","doc":"The pipeline parses, decodes a sample opus file and then saves it as a raw file:\n\n```elixir\ndefmodule Membrane.ReleaseTest.Pipeline2 do\n  use Membrane.Pipeline\n\n  @input_filename \"/tmp/input.raw\"\n  @output_filename \"/tmp/output.opus\"\n\n  @impl true\n  def handle_init(_ctx, _options) do\n    structure = \n      child(:source, %Membrane.File.Source{\n        location: @input_filename\n      })\n      |> child(:parser, Membrane.Opus.Parser)\n      |> child(:opus, Membrane.Opus.Decoder)\n      |> child(:sink, %Membrane.File.Sink{\n        location: @output_filename\n      })\n\n    {[spec: structure], %{}}\n  end\nend\n```","ref":"readme.html#decoder"},{"type":"extras","title":"Copyright and License - Membrane Opus plugin","doc":"Copyright 2019, [Software Mansion](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_opus_plugin)\n\n[![Software Mansion](https://logo.swmansion.com/logo?color=white&variant=desktop&width=200&tag=membrane-github)](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_opus_plugin)\n\nLicensed under the [Apache License, Version 2.0](LICENSE)","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2018 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown"}